intelmq.bots.experts.reverse_dns package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.reverse_dns package

## Submodules

## intelmq.bots.experts.reverse_dns.expert module

intelmq.bots.experts.reverse_dns.expert.BOT

  alias of `intelmq.bots.experts.reverse_dns.expert.ReverseDnsExpertBot`

exception intelmq.bots.experts.reverse_dns.expert.InvalidPTRResult

  Bases: `ValueError`

class intelmq.bots.experts.reverse_dns.expert.ReverseDnsExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`, `intelmq.lib.mixins.cache.CacheMixin`

  Get the correspondent domain name for source and destination IP address

  cache_ttl_invalid_response: int = 60
  overwrite: bool = False
  process()
  redis_cache_db: int = 7
  redis_cache_host: str = '127.0.0.1'
  redis_cache_password: str = None
  redis_cache_port: int = 6379
  redis_cache_ttl: int = 86400

## Module contents